# This file was auto-generated by Fern from our API Definition.

import typing_extensions


class FileFromUrlSettingsParams(typing_extensions.TypedDict):
    """
    Optional settings for the file, such as a password for password-protected PDFs.
    """

    password: typing_extensions.NotRequired[str]
    """
    The password to unlock a password-protected PDF.
    """
