# This file was auto-generated by Fern from our API Definition.

import typing_extensions
from ..core.serialization import FieldMetadata
from ..types.processor_version_string import ProcessorVersionString
from .classify_override_config import ClassifyOverrideConfigParams


class ClassifyRequestClassifierParams(typing_extensions.TypedDict):
    """
    Reference to an existing classifier. One of `classifier` or `config` must be provided.
    """

    id: str
    """
    The ID of the classifier to use.
    """

    version: typing_extensions.NotRequired[ProcessorVersionString]
    override_config: typing_extensions.NotRequired[
        typing_extensions.Annotated[ClassifyOverrideConfigParams, FieldMetadata(alias="overrideConfig")]
    ]
    """
    Optional partial configuration override. Only the fields you provide will override the classifier's saved configuration. For example, you can pass only `classificationRules` without providing `classifications`.
    """
