# This file was auto-generated by Fern from our API Definition.

import typing

from ...requests.file_from_id import FileFromIdParams
from ...requests.file_from_url import FileFromUrlParams

ParseRunsCreateRequestFileParams = typing.Union[FileFromUrlParams, FileFromIdParams]
