# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2
from ..core.unchecked_base_model import UncheckedBaseModel


class FileFromId(UncheckedBaseModel):
    """
    An Extend file ID (for instance from another run or a previous file upload).
    """

    id: str = pydantic.Field()
    """
    An Extend file ID.
    
    Example: `"file_xK9mLPqRtN3vS8wF5hB2cQ"`
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
