# This file was auto-generated by Fern from our API Definition.

import typing

from ..core import enum

T_Result = typing.TypeVar("T_Result")


class LegacyClassificationConfigBaseProcessor(enum.StrEnum):
    """
    The base processor to use. For classifiers, this must be either `"classification_performance"` or `"classification_light"`. See [Classification Changelog](https://docs.extend.ai/2026-02-09/changelog/classification/classification-performance) for more details.
    """

    CLASSIFICATION_PERFORMANCE = "classification_performance"
    CLASSIFICATION_LIGHT = "classification_light"
    _UNKNOWN = "__LEGACYCLASSIFICATIONCONFIGBASEPROCESSOR_UNKNOWN__"
    """
    This member is used for forward compatibility. If the value is not recognized by the enum, it will be stored here, and the raw value is accessible through `.value`.
    """

    @classmethod
    def _missing_(cls, value: typing.Any) -> "LegacyClassificationConfigBaseProcessor":
        unknown = cls._UNKNOWN
        unknown._value_ = value
        return unknown

    def visit(
        self,
        classification_performance: typing.Callable[[], T_Result],
        classification_light: typing.Callable[[], T_Result],
        _unknown_member: typing.Callable[[str], T_Result],
    ) -> T_Result:
        if self is LegacyClassificationConfigBaseProcessor.CLASSIFICATION_PERFORMANCE:
            return classification_performance()
        if self is LegacyClassificationConfigBaseProcessor.CLASSIFICATION_LIGHT:
            return classification_light()
        return _unknown_member(self._value_)
