# This file was auto-generated by Fern from our API Definition.

import typing

from ..core import enum

T_Result = typing.TypeVar("T_Result")


class ExtractChunkingOptionsChunkingStrategy(enum.StrEnum):
    """
    The strategy to use for chunking the document.
    """

    STANDARD = "standard"
    SEMANTIC = "semantic"
    CONTEXTUAL = "contextual"
    _UNKNOWN = "__EXTRACTCHUNKINGOPTIONSCHUNKINGSTRATEGY_UNKNOWN__"
    """
    This member is used for forward compatibility. If the value is not recognized by the enum, it will be stored here, and the raw value is accessible through `.value`.
    """

    @classmethod
    def _missing_(cls, value: typing.Any) -> "ExtractChunkingOptionsChunkingStrategy":
        unknown = cls._UNKNOWN
        unknown._value_ = value
        return unknown

    def visit(
        self,
        standard: typing.Callable[[], T_Result],
        semantic: typing.Callable[[], T_Result],
        contextual: typing.Callable[[], T_Result],
        _unknown_member: typing.Callable[[str], T_Result],
    ) -> T_Result:
        if self is ExtractChunkingOptionsChunkingStrategy.STANDARD:
            return standard()
        if self is ExtractChunkingOptionsChunkingStrategy.SEMANTIC:
            return semantic()
        if self is ExtractChunkingOptionsChunkingStrategy.CONTEXTUAL:
            return contextual()
        return _unknown_member(self._value_)
