# This file was auto-generated by Fern from our API Definition.

from __future__ import annotations

import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2, update_forward_refs
from ..core.serialization import FieldMetadata
from ..core.unchecked_base_model import UncheckedBaseModel
from .extract_run import ExtractRun
from .merge_extract_result_merged_extractors_item import MergeExtractResultMergedExtractorsItem


class MergeExtractResult(UncheckedBaseModel):
    """
    The result of a merge extract step, which combines outputs from multiple extraction runs into a single output.
    """

    merged_extractors: typing_extensions.Annotated[
        typing.List[MergeExtractResultMergedExtractorsItem], FieldMetadata(alias="mergedExtractors")
    ] = pydantic.Field(alias="mergedExtractors")
    """
    The extractors that were merged to produce the output.
    """

    extract_run: typing_extensions.Annotated[ExtractRun, FieldMetadata(alias="extractRun")] = pydantic.Field(
        alias="extractRun"
    )
    """
    The resulting extract run containing the merged output.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow


update_forward_refs(MergeExtractResult)
